==> mimultiplicacion-0.2.tar.gz: mimultiplicacion-0.2/README.md <==
# PyMiau
## Use a short explanatory subtitle like, Make a Miau and a Guau

<!-- This are visual tags that you may add to your package at the beginning with useful information on your package --> 
[![version](https://img.shields.io/pypi/v/mimultiplicacion?color=blue)](https://pypi.org/project/mimultiplicacion/)
[![downloads](https://img.shields.io/pypi/dw/pymiau)](https://pypi.org/project/mimultiplicacion/)

Always start the README explaining clearly what your package do.  If
you can include here some beautiful image to call the attention of the
potential user do it!

This is an example:

<p align="center"><img src="https://img.freepik.com/premium-vector/multiplication-table-with-cats_118813-3728.jpg?w=740" alt="Logo""/></p>

## Download and install

Describe here how the package can be downloaded and install it in
different arquitectures.

If you are using `PyPI` installation it's as simple as:

```
pip install pymiau
```

You can also test the unstable version of the package with:

```
pip install -i https://test.pypi.org/simple/ pymiau
```

## Quick start

In this section you should provide the most simple instructions to use
your package.

For instance:

```
import pymiau
print(pymiau.miau())
```

## Code examples

Provide some detailed examples for more advanced users.

For instance:

```
import pymiau
print(pymiau.miau(n=2))
```

## What's new

If your package will be frequently updated with new features include a
section describing the new features added to it:

Version 0.2:

- Function `guau` was implemented.
- New parameters added to the `miau` routine.

Version 0.1:

- First version of the package.

------------

This package has been designed and written by Fulanit@ de Tal (C) 2023

==> mimultiplicacion-0.3.tar.gz: mimultiplicacion-0.3/README.md <==
# mimultiplicacion
## make a multiplication

<!-- This are visual tags that you may add to your package at the beginning with useful information on your package --> 
[![version](https://img.shields.io/pypi/v/mimultiplicacion?color=blue)](https://pypi.org/project/mimultiplicacion/)
[![downloads](https://img.shields.io/pypi/dw/pymiau)](https://pypi.org/project/mimultiplicacion/)

Always start the README explaining clearly what your package do.  If
you can include here some beautiful image to call the attention of the
potential user do it!

This is an example:

<p align="center"><img src="https://img.freepik.com/premium-vector/multiplication-table-with-cats_118813-3728.jpg?w=740" alt="Logo""/></p>

## Download and install

Describe here how the package can be downloaded and install it in
different arquitectures.

If you are using `PyPI` installation it's as simple as:

```
pip install mimultiplicacion
```

You can also test the unstable version of the package with:

```
pip install -i https://test.pypi.org/simple/ mimultiplicacion
```

## Quick start

In this section you should provide the most simple instructions to use
your package.

For instance:

```
import mimultiplicacion
print(mimultiplicacion.saludo_inicial())
```

## Code examples

Provide some detailed examples for more advanced users.

For instance:

```
import pymiau
print(pymiau.miau(n=2))
```

## What's new

If your package will be frequently updated with new features include a
section describing the new features added to it:

Version 0.3:

- Function `saludo_inicial` was implemented.
- Function `multiplica_dos_numeros` was implemented.

Version 0.1:

- First version of the package.

------------

This package has been designed and written by Fulanit@ de Tal (C) 2023
